==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebFilteringOptionsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFilteringOptionsDescription } from "./WebFilteringOptionsDescription";
/**
 * @hidden
 */
export let WebFilteringOptionsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebFilteringOptionsDescriptionMetadata extends Base {
        static b(a) {
            if (WebFilteringOptionsDescriptionMetadata.a == null) {
                WebFilteringOptionsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebFilteringOptionsDescriptionMetadata.c(WebFilteringOptionsDescriptionMetadata.a);
            }
            if (a.k(WebFilteringOptionsDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebFilteringOptionsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:FilteringOptions");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        }
        static d(a) {
            WebFilteringOptionsDescriptionMetadata.b(a);
            a.ad("WebFilteringOptions", () => new WebFilteringOptionsDescription());
            a.ac("WebFilteringOptions", WebFilteringOptionsDescriptionMetadata.a);
        }
    }
    WebFilteringOptionsDescriptionMetadata.$t = markType(WebFilteringOptionsDescriptionMetadata, 'WebFilteringOptionsDescriptionMetadata');
    WebFilteringOptionsDescriptionMetadata.a = null;
    return WebFilteringOptionsDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebFilteringOptionsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFilteringOptionsDescription } from "./WebFilteringOptionsDescription";
/**
 * @hidden
 */
export let WebFilteringOptionsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebFilteringOptionsDescriptionMetadata extends Base {
        static b(a) {
            if (WebFilteringOptionsDescriptionMetadata.a == null) {
                WebFilteringOptionsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebFilteringOptionsDescriptionMetadata.c(WebFilteringOptionsDescriptionMetadata.a);
            }
            if (a.k(WebFilteringOptionsDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebFilteringOptionsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:FilteringOptions");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        }
        static d(a) {
            WebFilteringOptionsDescriptionMetadata.b(a);
            a.ae("WebFilteringOptions", () => new WebFilteringOptionsDescription());
            a.ad("WebFilteringOptions", WebFilteringOptionsDescriptionMetadata.a);
        }
    }
    WebFilteringOptionsDescriptionMetadata.$t = markType(WebFilteringOptionsDescriptionMetadata, 'WebFilteringOptionsDescriptionMetadata');
    WebFilteringOptionsDescriptionMetadata.a = null;
    return WebFilteringOptionsDescriptionMetadata;
})();
